weaviate.batch package
======================

.. automodule:: weaviate.batch
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.batch.crud\_batch module
---------------------------------

.. automodule:: weaviate.batch.crud_batch
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.batch.requests module
------------------------------

.. automodule:: weaviate.batch.requests
   :members:
   :undoc-members:
   :show-inheritance:
